# Menghitung Luas Lingkaran
hitung luas lingkaran

## Installation
```shell
pip install lingkar33423322
```

## Usage
Basic Usage:
```python
from lingkar33423322 import lingkar

hi = Lingkaran.hitung_luas()
print(f"Luas lingkaran: {hi}")
```